/**
 * @file error.h
 * @brief Error codes description
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2021-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.1.0
 **/

#ifndef _CBOOT_ERROR_H
#define _CBOOT_ERROR_H

//Dependencies
#include "error.h"

// C++ guard
#ifdef __cplusplus
extern "C"
{
#endif

/**
 * @brief Error codes
 **/

typedef enum
{

    CBOOT_NO_ERROR = ERROR_PARTIAL_MATCH + 1,      ///< CBOOT Success
    CBOOT_ERROR_FAILURE,                           ///< CBOOT error code

    CBOOT_ERROR_INVALID_PARAMETERS,

    CBOOT_ERROR_INVALID_IMAGE_HEADER,
    CBOOT_ERROR_INVALID_IMAGE_CHECK,
    CBOOT_ERROR_MISSING_IMAGE_CHECK_METHOD,
    CBOOT_ERROR_INCOMPATIBLE_IMAGE_APP_VERSION,

    CBOOT_ERROR_INVALID_IMAGE_INTEGRITY_TAG,
    CBOOT_ERROR_INVALID_IMAGE_AUTHENTICATION_TAG,

    CBOOT_ERROR_INVALID_IMAGE_APP,

    CBOOT_ERROR_IMAGE_NOT_READY,

    CBOOT_ERROR_INVALID_STATE,

    CBOOT_ERROR_BUFFER_OVERFLOW,

} cboot_error_t;

// C++ guard
#ifdef __cplusplus
}
#endif

#endif
