/**
 * @file cipher.h
 * @brief CycloneBOOT Encryption & Decryption handling
 *
 * @section License
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * Copyright (C) 2021-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Open.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.1.0
 **/

#ifndef _IAP_CIPHER_H
#define _IAP_CIPHER_H

//Dependencies
#include "iap/iap.h"
#include "cipher/cipher_algorithms.h"

// Cipher initialization vector maximum size
#define MAX_CIPHER_IV_SIZE MAX_CIPHER_BLOCK_SIZE

/**
 * @brief Cipher engine structure definition
 **/

typedef struct
{
   CipherContext context;
   const CipherAlgo *algo;
   CipherMode mode;
   const char_t *key;
   uint8_t iv[MAX_CIPHER_IV_SIZE];
   size_t ivLen;
} CipherEngine;


//CycloneBOOT cipher engine related functions
error_t cipherInit(CipherEngine *engine, const CipherAlgo *algo,
   CipherMode mode, const char_t *key, size_t keyLen);
error_t cipherSetIv(CipherEngine *engine, uint8_t* iv, size_t ivLen);
error_t cipherEncryptData(CipherEngine *cipherEngine, uint8_t *data, size_t length);
error_t cipherDecryptData(CipherEngine *cipherEngine, uint8_t *data, size_t length);

#endif // !_IAP_CIPHER_H
